unit DllDecl;
{* DESCRIPTION
 *   This unit contains all definitions and declarations that are required
 *   to use a TiePie instrument in a Delphi application.
 *   This is a universal unit, therefor it may contain definitions and declarations
 *   that are not supported by the instrument you are writing software for.
 *   Using these will be handled properly by the dll and should not cause problems
 * NOTE
 *   Despite the care taken to generate the dll's and the accomanying files,
 *   TiePie engineering can not be held responsible for any damage as a result of using
 *   the dll's and the accompanying source files.
 * COPYRIGHT
 *   TiePie engineering
 *}
interface

uses Windows;

const
//  Return codes = bit values. Non-zero is an error:
  E_NO_ERRORS            = $0000;
  E_NO_HARDWARE          = $0001;
  E_NOT_INITIALIZED      = $0002;
  E_NOT_SUPPORTED        = $0004;
  E_NO_GENERATOR         = $0008;
  E_INVALID_CHANNEL      = $0010;
  E_INVALID_VALUE        = $0020;
  E_I2C_ERROR            = $0040;
  E_I2C_INVALID_ADDRESS  = $0080;
  E_I2C_INVALID_SIZE     = $0100;
  E_I2C_NO_ACKNOWLEDGE   = $0200;

//  Channel constants:
  lCh1                   =  1;
  lCh2                   =  2;
  lCh3                   =  3;
  lCh4                   =  4;

//  Measure Mode constants, do NOT use for anything else than G/SetMeasureMode().
//  When measuring more channels, simply add the required constants together : e.g. mmCh1 + mmCh2 to measure both Ch1 and Ch2
  mmCh1                  =  1;
  mmCh2                  =  2;
  mmCh3                  =  4;
  mmCh4                  =  8;
  mmCh12                 =  3;

//  Coupling constants:
  lctAC                  =  0;
  lctDC                  =  1;

//  Trigger mode constants:
  ltkRising              =  0; //  Trigger when signal passes level in positive direction
  ltkFalling             =  1; //  Trigger when signal passes level in negative direction
  ltkInWindow            =  2; //  Trigger when signal enters marked window
  ltkOutWindow           =  3; //  Trigger when signal leaves marked window
  ltkTVLine              =  4; //  Trigger at TV line sync pulse
  ltkTVFieldOdd          =  5; //  Trigger at Odd TV field sync pulse
  ltkTVFieldEven         =  6; //  Trigger at Even TV field sync pulse
  ltkNet                 =  7; //  Trigger on peaks/dips in the line net
  ltkNthPulse            =  8; //  Trigger on the nth pulse after start of measuring
  ltkPulseLargerM        =  9; //  Trigger if a pulse is larger than M
  ltkPulseSmallerM       = 10; //  Trigger if a pulse is smaller than M
  ltkGlitch              = 11; //  Trigger when the change between two samples is larger than x

//  Trigger source constants for G/SetTriggerSource.
//  It is recommended to use the new routines GetTriggerSources, G/SetTriggerSourceOR and G/SetTriggerSourceAND,
//  with the TS_ constants instead.
  ltsCh1                 =  0; //  Trigger on Ch1
  ltsCh2                 =  1; //  Trigger on Ch2
  ltsCh3                 =  2; //  Trigger on Ch3
  ltsCh4                 =  3; //  Trigger on Ch4
  ltsExternal            =  4; //  Trigger on digital external trigger input
  ltsAnalogExt           =  5; //  Trigger on analog external trigger input
  ltsAnd                 =  6; //  Trigger on Ch1 AND Ch2
  ltsOr                  =  7; //  Trigger on Ch1 OR  Ch2
  ltsXor                 =  8; //  Trigger on Ch1 XOR Ch2
  ltsNoTrig              =  9; //  Do not wait for trigger, measure immediately
  ltsNeverTrig           = 10; //  not used
  ltsPxiExt              = 11; //  Trigger on external PXI trigger inputs
  ltsGenStart            = 12; //  Trigger on Generator Start Signal
  ltsGenStop             = 13; //  Trigger on Generator Stop Signal
  ltsGenNew              = 14; //  Trigger on Generator New Period
  ltsUnknown             = 15; //  not used

//  Trigger source constants for GetTriggerSources, G/SetTriggerSourceOR and G/SetTriggerSourceAND:
  TS_CH1                 = $0000000000000001; //  2^0
  TS_CH2                 = $0000000000000002; //  2^1
  TS_CH3                 = $0000000000000004; //  2^2
  TS_CH4                 = $0000000000000008; //  ...
  TS_CH5                 = $0000000000000010;
  TS_CH6                 = $0000000000000020;
  TS_CH7                 = $0000000000000040;
  TS_CH8                 = $0000000000000080;
  TS_CHANNELS            = $00000000FFFFFFFF; //  32 channel trigger sources

  TS_EXT                 = $8000000000000000; //  external digital trigger
  TS_EXTANALOG           = $4000000000000000; //  external analog trigger
  TS_EXTPXI              = $2000000000000000; //  external PXI trigger
  TS_GENSTART            = $1000000000000000; //  trigger when internal function generator starts
  TS_GENNEW              = $0800000000000000; //  trigger when internal function generator starts a new period
  TS_GENSTOP             = $0400000000000000; //  trigger when internal function generator stops
  TS_OTHERSOURCES        = $FFFFFFFF00000000; //  32 bits reserved for other trigger sources

//  Transfer mode constants:
  ltmBlock               =  0;
  ltmStream              =  1;

//  Instrument Configuration constants:
  licHS3Norm             =  0;
  licHS3256K             =  1;
  licHS3512K             =  2;

//  === Function Generator constants ===

//  FuncGen Modes:
  lfmDDS                 =  1;
  lfmLinear              =  2;

//  Signal types
  lstSine                =  0;
  lstTriangle            =  1;
  lstSquare              =  2;
  lstDC                  =  3;
  lstNoise               =  4;
  lstArbitrary           =  5;


type
  ERROR             = word;
  DArray            = array[0 .. 512 * 1024] of double;
  PDArray           = ^DArray;
  PDouble           = ^Double;
  Pbyte             = ^byte;
  PWord             = ^word;
  PDword            = ^dword;
  TWArray           = array [0 .. 512 * 1024] of word;
  TWArray2          = array [0 .. 512 * 1024] of word;
  PTWArray          = ^TWArray;
  PTDarray          = ^DArray;
  TInfoArray        = array[0 .. 19] of double;
  PInfoArray        = ^TInfoArray;
  TDataReady        = procedure; stdcall;
 {*
  * Function prototypes
  *}

//  Open / Close the instrument:
  TInitInstrument = function( wInstrumentCount : Word ) : ERROR; stdcall;
  TExitInstrument = function : ERROR; stdcall;
 
//  Get information about the instrument:
  TGetCalibrationDate = function( dwDate : PDWORD ) : ERROR; stdcall;
  TGetSerialNumber = function( dwSerialNumber : PDWORD ) : ERROR; stdcall;
  TGetAvailableSensitivities = function( dSensitivities : PInfoArray ) : ERROR; stdcall;
  TGetAvailableResolutions = function( dResolutions : PInfoArray ) : ERROR; stdcall;
  TGetNrChannels = function( wValue : PWord ) : ERROR; stdcall;
  TGetMaxSampleFrequencyF = function : Double; stdcall;
  TGetMaxRecordLength = function : DWORD; stdcall;
  TGetDCLevelStatus = function : DWORD; stdcall;
 
//  Measurement routines:
  TADC_Start = function : ERROR; stdcall;
  TADC_Running = function : Word; stdcall;
  TADC_Abort = function : ERROR; stdcall;
  TADC_ForceTrig = function : ERROR; stdcall;
  TADC_Triggered = function : Word; stdcall;
  TADC_Ready = function : Word; stdcall;
 
//  Retrieve the measured data:
  TADC_GetDataCh = function( wCh : Word ; wChData : PTWArray ) : ERROR; stdcall;
  TADC_GetDataVoltCh = function( wCh : Word ; dChData : PTDArray ) : ERROR; stdcall;
  TGetDigitalInputValues = function( wValues : PTWArray ) : ERROR; stdcall;
  TGetOneDigitalValue = function( dwIndex : DWORD ; wValue : PWord ) : ERROR; stdcall;
 
//  Control the input resolution in bits:
  TSetResolution = function( byValue : Byte ) : ERROR; stdcall;
  TGetResolution = function( byValue : PByte ) : ERROR; stdcall;
 
//  Control the instrument configuration:
  TSetInstrumentConfig = function( wMode : Word ) : ERROR; stdcall;
 
//  Control which channels are measured:
  TGetMeasureMode = function( byMode : PByte ) : ERROR; stdcall;
  TSetMeasureMode = function( byMode : Byte ) : ERROR; stdcall;
  TGetChEnabled = function( wCh : Word ; byEnabled : PByte ) : ERROR; stdcall;
  TSetChEnabled = function( wCh : Word ; byEnabled : Byte ) : ERROR; stdcall;
 
//  Control the time base:
  TGetRecordLength = function : DWORD; stdcall;
  TSetRecordLength = function( dwRecordLength : DWORD ) : ERROR; stdcall;
  TGetPostSamples = function : DWORD; stdcall;
  TSetPostSamples = function( dwPostSampleCount : DWORD ) : ERROR; stdcall;
  TGetSampleFrequencyF = function : Double; stdcall;
  TSetSampleFrequencyF = function( dFreq : PDouble ) : ERROR; stdcall;
  TGetExternalClock = function( wMode : PWord ) : ERROR; stdcall;
  TSetExternalClock = function( wMode : Word ) : ERROR; stdcall;
 
//  Control the analog input channels:
  TGetSensitivity = function( byCh : Byte ; dSensitivity : PDouble ) : ERROR; stdcall;
  TSetSensitivity = function( byCh : Byte ; dSensitivity : PDouble ) : ERROR; stdcall;
  TGetAutoRanging = function( byCh : Byte ; byMode : PByte ) : ERROR; stdcall;
  TSetAutoRanging = function( byCh : Byte ; byMode : Byte ) : ERROR; stdcall;
  TGetCoupling = function( byCh : Byte ; byMode : PByte ) : ERROR; stdcall;
  TSetCoupling = function( byCh : Byte ; byMode : Byte ) : ERROR; stdcall;
  TGetDcLevel = function( byCh : Byte ; dDcLevel : PDouble ) : ERROR; stdcall;
  TSetDcLevel = function( byCh : Byte ; dDcLevel : Double ) : ERROR; stdcall;
 
//  Control the trigger system:
  TGetTriggerTimeOut = function : DWORD; stdcall;
  TSetTriggerTimeOut = function( dwTimeout : DWORD ) : ERROR; stdcall;
  TGetTriggerSource = function( byTrigSource : PByte ) : ERROR; stdcall;
  TSetTriggerSource = function( byTrigSource : Byte ) : ERROR; stdcall;
//  For more control, use these routines for trigger source, instead of the ones above:
  TGetTriggerSources = function( nTrigMask : PInt64 ) : ERROR; stdcall;
  TGetTriggerSourceOR = function( nTrigMask : PInt64 ) : ERROR; stdcall;
  TSetTriggerSourceOR = function( nTrigMask : Int64 ) : ERROR; stdcall;
  TGetTriggerSourceAND = function( nTrigMask : PInt64 ) : ERROR; stdcall;
  TSetTriggerSourceAND = function( nTrigMask : Int64 ) : ERROR; stdcall;
  TGetTriggerMode = function( byMode : PByte ) : ERROR; stdcall;
  TSetTriggerMode = function( byMode : Byte ) : ERROR; stdcall;
  TGetTriggerModeCh = function( byCh : Byte ; byMode : PByte ) : ERROR; stdcall;
  TSetTriggerModeCh = function( byCh : Byte ; byMode : Byte ) : ERROR; stdcall;
  TGetTriggerLevel = function( byCh : Byte ; dLevel : PDouble ) : ERROR; stdcall;
  TSetTriggerLevel = function( byCh : Byte ; dLevel : Double ) : ERROR; stdcall;
  TGetTriggerHys = function( byCh : Byte ; dHysteresis : PDouble ) : ERROR; stdcall;
  TSetTriggerHys = function( byCh : Byte ; dHysteresis : Double ) : ERROR; stdcall;
  TGetPXITriggerEnables = function( byEnables : PByte ) : ERROR; stdcall;
  TSetPXITriggerEnables = function( byEnables : Byte ) : ERROR; stdcall;
  TGetPXITriggerSlopes = function( bySlopes : PByte ) : ERROR; stdcall;
  TSetPXITriggerSlopes = function( bySlopes : Byte ) : ERROR; stdcall;
 
//  Control the digital outputs:
  TSetDigitalOutputs = function( byValue : Byte ) : ERROR; stdcall;
  TGetDigitalOutputs = function( byValue : PByte ) : ERROR; stdcall;
 
//  Square Wave Generator:
  TGetSquareWaveGenStatus = function : ERROR; stdcall;
  TGetSquareWaveGenFrequency = function : DWORD; stdcall;
  TSetSquareWaveGenFrequency = function( dwFreq : PDWORD ) : ERROR; stdcall;
 
//  Get information about the function generator:
  TGetFunctionGenStatus = function : ERROR; stdcall;
  TGetFuncGenMaxAmplitude = function( dMaxAmplitude : PDouble ) : ERROR; stdcall;
 
//  Control the Arbitrary Waveform Generator:
  TGetFuncGenOutputOn = function( wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenOutputOn = function( wValue : Word ) : ERROR; stdcall;
  TGetFuncGenEnable = function( wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenEnable = function( wValue : Word ) : ERROR; stdcall;
  TGetFuncGenSignalType = function( wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenSignalType = function( wValue : Word ) : ERROR; stdcall;
  TGetFuncGenMode = function( dwMode : PDWORD ) : ERROR; stdcall;
  TSetFuncGenMode = function( dwMode : DWORD ) : ERROR; stdcall;
  TGetFuncGenAmplitude = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenAmplitude = function( dValue : Double ) : ERROR; stdcall;
  TGetFuncGenDCOffset = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenDCOffset = function( dValue : Double ) : ERROR; stdcall;
  TGetFuncGenSymmetry = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenSymmetry = function( dValue : Double ) : ERROR; stdcall;
  TGetFuncGenFrequency = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenFrequency = function( dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenTrigSource = function( byTrigSource : Byte ) : ERROR; stdcall;
  TGetFuncGenTrigSource = function( byTrigSource : PByte ) : ERROR; stdcall;
  TFillFuncGenMemory = function( dwSampleCount : DWORD ; FuncGenData : PTWArray ) : ERROR; stdcall;
  TFuncGenBurst = function( wNrPeriods : Word ) : ERROR; stdcall;
 
//  Control multiple Arbitrary Waveform Generators:
  TGetFunctionGeneratorCount = function : Word; stdcall;
 
  TGetFuncGenOutputOnCh = function( wCh : Word ; wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenOutputOnCh = function( wCh : Word ; wValue : Word ) : ERROR; stdcall;
  TGetFuncGenEnableCh = function( wCh : Word ; wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenEnableCh = function( wCh : Word ; wValue : Word ) : ERROR; stdcall;
  TGetFuncGenSignalTypeCh = function( wCh : Word ; wValue : PWord ) : ERROR; stdcall;
  TSetFuncGenSignalTypeCh = function( wCh : Word ; wValue : Word ) : ERROR; stdcall;
  TGetFuncGenModeCh = function( wCh : Word ; dwMode : PDWORD ) : ERROR; stdcall;
  TSetFuncGenModeCh = function( wCh : Word ; dwMode : DWORD ) : ERROR; stdcall;
  TGetFuncGenMaxAmplitudeCh = function( wCh : Word ; dValue : PDouble ) : ERROR; stdcall;
  TGetFuncGenAmplitudeCh = function( wCh : Word ; dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenAmplitudeCh = function( wCh : Word ; dValue : Double ) : ERROR; stdcall;
  TGetFuncGenDCOffsetCh = function( wCh : Word ; dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenDCOffsetCh = function( wCh : Word ; dValue : Double ) : ERROR; stdcall;
  TGetFuncGenSymmetryCh = function( wCh : Word ; dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenSymmetryCh = function( wCh : Word ; dValue : Double ) : ERROR; stdcall;
  TGetFuncGenFrequencyCh = function( wCh : Word ; dValue : PDouble ) : ERROR; stdcall;
  TSetFuncGenFrequencyCh = function( wCh : Word ; dValue : PDouble ) : ERROR; stdcall;
  TGetFuncGenTrigSourceCh = function( wCh : Word ; byTrigSource : PByte ) : ERROR; stdcall;
  TSetFuncGenTrigSourceCh = function( wCh : Word ; byTrigSource : Byte ) : ERROR; stdcall;
  TFillFuncGenMemoryCh = function( wCh : Word ; dwSampleCount : DWORD ; FuncGenData : PTWArray ) : ERROR; stdcall;
  TFuncGenBurstCh = function( wCh : Word ; wNrPeriods : Word ) : ERROR; stdcall;
 
//  Ohm measurements ( not available by default ):
  TSetupOhmMeasurements = function( wMode : Word ) : ERROR; stdcall;
  TGetOhmValues = function( dValue1 : PDouble ; dValue2 : PDouble ) : ERROR; stdcall;
 
//  I2C routines:
  TI2CWrite = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CWriteNoStop = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CRead = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CReadNoStop = function( dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CGetSpeed = function( dwSpeed : PDWORD ) : ERROR; stdcall;
  TI2CSetSpeed = function( dwSpeed : PDWORD ) : ERROR; stdcall;
 
//  I2C routines for acces to I2C-buses other than that of the first instrument:
  TI2CWriteCh = function( wCh : Word ; dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CWriteNoStopCh = function( wCh : Word ; dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CReadCh = function( wCh : Word ; dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CReadNoStopCh = function( wCh : Word ; dwAddress : DWORD ; pBuf : pointer ; dwSize : DWORD ) : ERROR; stdcall;
  TI2CGetSpeedCh = function( wCh : Word ; dwSpeed : PDWORD ) : ERROR; stdcall;
  TI2CSetSpeedCh = function( wCh : Word ; dwSpeed : PDWORD ) : ERROR; stdcall;
 
//  Obsolete routines, use is deprecated:
  TStartMeasurement = function : ERROR; stdcall;
 
  TGetMeasurement = function( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR; stdcall;
  TGetMeasurementCh = function( wCh : Word ; dChData : PTDArray ) : ERROR; stdcall;
  TGetMeasurementRaw = function( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR; stdcall;
  TGetMeasurementRawCh = function( wCh : Word ; wChData : PTWArray ) : ERROR; stdcall;
  TGetOneMeasurement = function( dwIndex : DWORD ; dCh1 : PDouble ; dCh2 : PDouble ) : ERROR; stdcall;
  TGetOneMeasurementCh = function( wCh : Word ; dwIndex : DWORD ; dChData : PDouble ) : ERROR; stdcall;
  TGetOneMeasurementRaw = function( dwIndex : DWORD ; wCh1 : PWord ; wCh2 : PWord ) : ERROR; stdcall;
  TGetOneMeasurementRawCh = function( wCh : Word ; dwIndex : DWORD ; wChData : PWord ) : ERROR; stdcall;
  TADC_GetData = function( wCh1 : PTWArray ; wCh2 : PTWArray ) : ERROR; stdcall;
  TADC_GetDataVolt = function( dCh1 : PTDArray ; dCh2 : PTDArray ) : ERROR; stdcall;
 
  TGetMaxSampleFrequency = function : DWORD; stdcall;
  TGetSampleFrequency = function : DWORD; stdcall;
  TSetSampleFrequency = function( dwFreq : PDWORD ) : ERROR; stdcall;
 
//  Streaming measurements:
  TSetDataReadyCallback = function( pAddress : TDataReady ) : ERROR; stdcall;
  TSetDataReadyEvent = function( hEvent : THandle ) : ERROR; stdcall;
  TSetTransferMode = function( dwMode : DWORD ) : ERROR; stdcall;
  TGetTransferMode = function( dwMode : PDWORD ) : ERROR; stdcall;


var
  Ch1DoubleArray    : DArray;
  Ch2DoubleArray    : DArray;
  Ch3DoubleArray    : DArray;
  Ch4DoubleArray    : DArray;

  Ch1WordArray      : TWArray;
  Ch2WordArray      : TWArray;
  Ch3WordArray      : TWArray;
  Ch4WordArray      : TWArray;
  DigitalArray      : TWArray;
  FuncGenArray      : TWArray2;

  DllHandle         : THandle;

  WM_TRANS_UPDATE   : dword = 0;
  WM_TRANS_READY    : dword = 0;

//  Open / Close the instrument:
  InitInstrument : TInitInstrument = nil;
  ExitInstrument : TExitInstrument = nil;
 
//  Get information about the instrument:
  GetCalibrationDate : TGetCalibrationDate = nil;
  GetSerialNumber : TGetSerialNumber = nil;
  GetAvailableSensitivities : TGetAvailableSensitivities = nil;
  GetAvailableResolutions : TGetAvailableResolutions = nil;
  GetNrChannels : TGetNrChannels = nil;
  GetMaxSampleFrequencyF : TGetMaxSampleFrequencyF = nil;
  GetMaxRecordLength : TGetMaxRecordLength = nil;
  GetDCLevelStatus : TGetDCLevelStatus = nil;
 
//  Measurement routines:
  ADC_Start : TADC_Start = nil;
  ADC_Running : TADC_Running = nil;
  ADC_Abort : TADC_Abort = nil;
  ADC_ForceTrig : TADC_ForceTrig = nil;
  ADC_Triggered : TADC_Triggered = nil;
  ADC_Ready : TADC_Ready = nil;
 
//  Retrieve the measured data:
  ADC_GetDataCh : TADC_GetDataCh = nil;
  ADC_GetDataVoltCh : TADC_GetDataVoltCh = nil;
  GetDigitalInputValues : TGetDigitalInputValues = nil;
  GetOneDigitalValue : TGetOneDigitalValue = nil;
 
//  Control the input resolution in bits:
  SetResolution : TSetResolution = nil;
  GetResolution : TGetResolution = nil;
 
//  Control the instrument configuration:
  SetInstrumentConfig : TSetInstrumentConfig = nil;
 
//  Control which channels are measured:
  GetMeasureMode : TGetMeasureMode = nil;
  SetMeasureMode : TSetMeasureMode = nil;
  GetChEnabled : TGetChEnabled = nil;
  SetChEnabled : TSetChEnabled = nil;
 
//  Control the time base:
  GetRecordLength : TGetRecordLength = nil;
  SetRecordLength : TSetRecordLength = nil;
  GetPostSamples : TGetPostSamples = nil;
  SetPostSamples : TSetPostSamples = nil;
  GetSampleFrequencyF : TGetSampleFrequencyF = nil;
  SetSampleFrequencyF : TSetSampleFrequencyF = nil;
  GetExternalClock : TGetExternalClock = nil;
  SetExternalClock : TSetExternalClock = nil;
 
//  Control the analog input channels:
  GetSensitivity : TGetSensitivity = nil;
  SetSensitivity : TSetSensitivity = nil;
  GetAutoRanging : TGetAutoRanging = nil;
  SetAutoRanging : TSetAutoRanging = nil;
  GetCoupling : TGetCoupling = nil;
  SetCoupling : TSetCoupling = nil;
  GetDcLevel : TGetDcLevel = nil;
  SetDcLevel : TSetDcLevel = nil;
 
//  Control the trigger system:
  GetTriggerTimeOut : TGetTriggerTimeOut = nil;
  SetTriggerTimeOut : TSetTriggerTimeOut = nil;
  GetTriggerSource : TGetTriggerSource = nil;
  SetTriggerSource : TSetTriggerSource = nil;
//  For more control, use these routines for trigger source, instead of the ones above:
  GetTriggerSources : TGetTriggerSources = nil;
  GetTriggerSourceOR : TGetTriggerSourceOR = nil;
  SetTriggerSourceOR : TSetTriggerSourceOR = nil;
  GetTriggerSourceAND : TGetTriggerSourceAND = nil;
  SetTriggerSourceAND : TSetTriggerSourceAND = nil;
  GetTriggerMode : TGetTriggerMode = nil;
  SetTriggerMode : TSetTriggerMode = nil;
  GetTriggerModeCh : TGetTriggerModeCh = nil;
  SetTriggerModeCh : TSetTriggerModeCh = nil;
  GetTriggerLevel : TGetTriggerLevel = nil;
  SetTriggerLevel : TSetTriggerLevel = nil;
  GetTriggerHys : TGetTriggerHys = nil;
  SetTriggerHys : TSetTriggerHys = nil;
  GetPXITriggerEnables : TGetPXITriggerEnables = nil;
  SetPXITriggerEnables : TSetPXITriggerEnables = nil;
  GetPXITriggerSlopes : TGetPXITriggerSlopes = nil;
  SetPXITriggerSlopes : TSetPXITriggerSlopes = nil;
 
//  Control the digital outputs:
  SetDigitalOutputs : TSetDigitalOutputs = nil;
  GetDigitalOutputs : TGetDigitalOutputs = nil;
 
//  Square Wave Generator:
  GetSquareWaveGenStatus : TGetSquareWaveGenStatus = nil;
  GetSquareWaveGenFrequency : TGetSquareWaveGenFrequency = nil;
  SetSquareWaveGenFrequency : TSetSquareWaveGenFrequency = nil;
 
//  Get information about the function generator:
  GetFunctionGenStatus : TGetFunctionGenStatus = nil;
  GetFuncGenMaxAmplitude : TGetFuncGenMaxAmplitude = nil;
 
//  Control the Arbitrary Waveform Generator:
  GetFuncGenOutputOn : TGetFuncGenOutputOn = nil;
  SetFuncGenOutputOn : TSetFuncGenOutputOn = nil;
  GetFuncGenEnable : TGetFuncGenEnable = nil;
  SetFuncGenEnable : TSetFuncGenEnable = nil;
  GetFuncGenSignalType : TGetFuncGenSignalType = nil;
  SetFuncGenSignalType : TSetFuncGenSignalType = nil;
  GetFuncGenMode : TGetFuncGenMode = nil;
  SetFuncGenMode : TSetFuncGenMode = nil;
  GetFuncGenAmplitude : TGetFuncGenAmplitude = nil;
  SetFuncGenAmplitude : TSetFuncGenAmplitude = nil;
  GetFuncGenDCOffset : TGetFuncGenDCOffset = nil;
  SetFuncGenDCOffset : TSetFuncGenDCOffset = nil;
  GetFuncGenSymmetry : TGetFuncGenSymmetry = nil;
  SetFuncGenSymmetry : TSetFuncGenSymmetry = nil;
  GetFuncGenFrequency : TGetFuncGenFrequency = nil;
  SetFuncGenFrequency : TSetFuncGenFrequency = nil;
  SetFuncGenTrigSource : TSetFuncGenTrigSource = nil;
  GetFuncGenTrigSource : TGetFuncGenTrigSource = nil;
  FillFuncGenMemory : TFillFuncGenMemory = nil;
  FuncGenBurst : TFuncGenBurst = nil;
 
//  Control multiple Arbitrary Waveform Generators:
  GetFunctionGeneratorCount : TGetFunctionGeneratorCount = nil;
 
  GetFuncGenOutputOnCh : TGetFuncGenOutputOnCh = nil;
  SetFuncGenOutputOnCh : TSetFuncGenOutputOnCh = nil;
  GetFuncGenEnableCh : TGetFuncGenEnableCh = nil;
  SetFuncGenEnableCh : TSetFuncGenEnableCh = nil;
  GetFuncGenSignalTypeCh : TGetFuncGenSignalTypeCh = nil;
  SetFuncGenSignalTypeCh : TSetFuncGenSignalTypeCh = nil;
  GetFuncGenModeCh : TGetFuncGenModeCh = nil;
  SetFuncGenModeCh : TSetFuncGenModeCh = nil;
  GetFuncGenMaxAmplitudeCh : TGetFuncGenMaxAmplitudeCh = nil;
  GetFuncGenAmplitudeCh : TGetFuncGenAmplitudeCh = nil;
  SetFuncGenAmplitudeCh : TSetFuncGenAmplitudeCh = nil;
  GetFuncGenDCOffsetCh : TGetFuncGenDCOffsetCh = nil;
  SetFuncGenDCOffsetCh : TSetFuncGenDCOffsetCh = nil;
  GetFuncGenSymmetryCh : TGetFuncGenSymmetryCh = nil;
  SetFuncGenSymmetryCh : TSetFuncGenSymmetryCh = nil;
  GetFuncGenFrequencyCh : TGetFuncGenFrequencyCh = nil;
  SetFuncGenFrequencyCh : TSetFuncGenFrequencyCh = nil;
  GetFuncGenTrigSourceCh : TGetFuncGenTrigSourceCh = nil;
  SetFuncGenTrigSourceCh : TSetFuncGenTrigSourceCh = nil;
  FillFuncGenMemoryCh : TFillFuncGenMemoryCh = nil;
  FuncGenBurstCh : TFuncGenBurstCh = nil;
 
//  Ohm measurements ( not available by default ):
  SetupOhmMeasurements : TSetupOhmMeasurements = nil;
  GetOhmValues : TGetOhmValues = nil;
 
//  I2C routines:
  I2CWrite : TI2CWrite = nil;
  I2CWriteNoStop : TI2CWriteNoStop = nil;
  I2CRead : TI2CRead = nil;
  I2CReadNoStop : TI2CReadNoStop = nil;
  I2CGetSpeed : TI2CGetSpeed = nil;
  I2CSetSpeed : TI2CSetSpeed = nil;
 
//  I2C routines for acces to I2C-buses other than that of the first instrument:
  I2CWriteCh : TI2CWriteCh = nil;
  I2CWriteNoStopCh : TI2CWriteNoStopCh = nil;
  I2CReadCh : TI2CReadCh = nil;
  I2CReadNoStopCh : TI2CReadNoStopCh = nil;
  I2CGetSpeedCh : TI2CGetSpeedCh = nil;
  I2CSetSpeedCh : TI2CSetSpeedCh = nil;
 
//  Obsolete routines, use is deprecated:
  StartMeasurement : TStartMeasurement = nil;
 
  GetMeasurement : TGetMeasurement = nil;
  GetMeasurementCh : TGetMeasurementCh = nil;
  GetMeasurementRaw : TGetMeasurementRaw = nil;
  GetMeasurementRawCh : TGetMeasurementRawCh = nil;
  GetOneMeasurement : TGetOneMeasurement = nil;
  GetOneMeasurementCh : TGetOneMeasurementCh = nil;
  GetOneMeasurementRaw : TGetOneMeasurementRaw = nil;
  GetOneMeasurementRawCh : TGetOneMeasurementRawCh = nil;
  ADC_GetData : TADC_GetData = nil;
  ADC_GetDataVolt : TADC_GetDataVolt = nil;
 
  GetMaxSampleFrequency : TGetMaxSampleFrequency = nil;
  GetSampleFrequency : TGetSampleFrequency = nil;
  SetSampleFrequency : TSetSampleFrequency = nil;
 
//  Streaming measurements:
  SetDataReadyCallback : TSetDataReadyCallback = nil;
  SetDataReadyEvent : TSetDataReadyEvent = nil;
  SetTransferMode : TSetTransferMode = nil;
  GetTransferMode : TGetTransferMode = nil;



procedure RetrieveAllProcAddresses;
procedure NilAllProcAddresses;


implementation


procedure RetrieveAllProcAddresses;
{* DESCRIPTION
 *   This routine gets the procedure addresses of all routines in the dll
 *   It should be called after the dll has been loaded and the global variable
 *   DLLHandle points to the proper dll.
 * INPUT
 *   -
 * OUTPUT
 *   -
 *}
begin
//  Open / Close the instrument:
  @InitInstrument := GetProcAddress( DLLHandle, 'InitInstrument' );
  @ExitInstrument := GetProcAddress( DLLHandle, 'ExitInstrument' );
 
//  Get information about the instrument:
  @GetCalibrationDate := GetProcAddress( DLLHandle, 'GetCalibrationDate' );
  @GetSerialNumber := GetProcAddress( DLLHandle, 'GetSerialNumber' );
  @GetAvailableSensitivities := GetProcAddress( DLLHandle, 'GetAvailableSensitivities' );
  @GetAvailableResolutions := GetProcAddress( DLLHandle, 'GetAvailableResolutions' );
  @GetNrChannels := GetProcAddress( DLLHandle, 'GetNrChannels' );
  @GetMaxSampleFrequencyF := GetProcAddress( DLLHandle, 'GetMaxSampleFrequencyF' );
  @GetMaxRecordLength := GetProcAddress( DLLHandle, 'GetMaxRecordLength' );
  @GetDCLevelStatus := GetProcAddress( DLLHandle, 'GetDCLevelStatus' );
 
//  Measurement routines:
  @ADC_Start := GetProcAddress( DLLHandle, 'ADC_Start' );
  @ADC_Running := GetProcAddress( DLLHandle, 'ADC_Running' );
  @ADC_Abort := GetProcAddress( DLLHandle, 'ADC_Abort' );
  @ADC_ForceTrig := GetProcAddress( DLLHandle, 'ADC_ForceTrig' );
  @ADC_Triggered := GetProcAddress( DLLHandle, 'ADC_Triggered' );
  @ADC_Ready := GetProcAddress( DLLHandle, 'ADC_Ready' );
 
//  Retrieve the measured data:
  @ADC_GetDataCh := GetProcAddress( DLLHandle, 'ADC_GetDataCh' );
  @ADC_GetDataVoltCh := GetProcAddress( DLLHandle, 'ADC_GetDataVoltCh' );
  @GetDigitalInputValues := GetProcAddress( DLLHandle, 'GetDigitalInputValues' );
  @GetOneDigitalValue := GetProcAddress( DLLHandle, 'GetOneDigitalValue' );
 
//  Control the input resolution in bits:
  @SetResolution := GetProcAddress( DLLHandle, 'SetResolution' );
  @GetResolution := GetProcAddress( DLLHandle, 'GetResolution' );
 
//  Control the instrument configuration:
  @SetInstrumentConfig := GetProcAddress( DLLHandle, 'SetInstrumentConfig' );
 
//  Control which channels are measured:
  @GetMeasureMode := GetProcAddress( DLLHandle, 'GetMeasureMode' );
  @SetMeasureMode := GetProcAddress( DLLHandle, 'SetMeasureMode' );
  @GetChEnabled := GetProcAddress( DLLHandle, 'GetChEnabled' );
  @SetChEnabled := GetProcAddress( DLLHandle, 'SetChEnabled' );
 
//  Control the time base:
  @GetRecordLength := GetProcAddress( DLLHandle, 'GetRecordLength' );
  @SetRecordLength := GetProcAddress( DLLHandle, 'SetRecordLength' );
  @GetPostSamples := GetProcAddress( DLLHandle, 'GetPostSamples' );
  @SetPostSamples := GetProcAddress( DLLHandle, 'SetPostSamples' );
  @GetSampleFrequencyF := GetProcAddress( DLLHandle, 'GetSampleFrequencyF' );
  @SetSampleFrequencyF := GetProcAddress( DLLHandle, 'SetSampleFrequencyF' );
  @GetExternalClock := GetProcAddress( DLLHandle, 'GetExternalClock' );
  @SetExternalClock := GetProcAddress( DLLHandle, 'SetExternalClock' );
 
//  Control the analog input channels:
  @GetSensitivity := GetProcAddress( DLLHandle, 'GetSensitivity' );
  @SetSensitivity := GetProcAddress( DLLHandle, 'SetSensitivity' );
  @GetAutoRanging := GetProcAddress( DLLHandle, 'GetAutoRanging' );
  @SetAutoRanging := GetProcAddress( DLLHandle, 'SetAutoRanging' );
  @GetCoupling := GetProcAddress( DLLHandle, 'GetCoupling' );
  @SetCoupling := GetProcAddress( DLLHandle, 'SetCoupling' );
  @GetDcLevel := GetProcAddress( DLLHandle, 'GetDcLevel' );
  @SetDcLevel := GetProcAddress( DLLHandle, 'SetDcLevel' );
 
//  Control the trigger system:
  @GetTriggerTimeOut := GetProcAddress( DLLHandle, 'GetTriggerTimeOut' );
  @SetTriggerTimeOut := GetProcAddress( DLLHandle, 'SetTriggerTimeOut' );
  @GetTriggerSource := GetProcAddress( DLLHandle, 'GetTriggerSource' );
  @SetTriggerSource := GetProcAddress( DLLHandle, 'SetTriggerSource' );
//  For more control, use these routines for trigger source, instead of the ones above:
  @GetTriggerSources := GetProcAddress( DLLHandle, 'GetTriggerSources' );
  @GetTriggerSourceOR := GetProcAddress( DLLHandle, 'GetTriggerSourceOR' );
  @SetTriggerSourceOR := GetProcAddress( DLLHandle, 'SetTriggerSourceOR' );
  @GetTriggerSourceAND := GetProcAddress( DLLHandle, 'GetTriggerSourceAND' );
  @SetTriggerSourceAND := GetProcAddress( DLLHandle, 'SetTriggerSourceAND' );
  @GetTriggerMode := GetProcAddress( DLLHandle, 'GetTriggerMode' );
  @SetTriggerMode := GetProcAddress( DLLHandle, 'SetTriggerMode' );
  @GetTriggerModeCh := GetProcAddress( DLLHandle, 'GetTriggerModeCh' );
  @SetTriggerModeCh := GetProcAddress( DLLHandle, 'SetTriggerModeCh' );
  @GetTriggerLevel := GetProcAddress( DLLHandle, 'GetTriggerLevel' );
  @SetTriggerLevel := GetProcAddress( DLLHandle, 'SetTriggerLevel' );
  @GetTriggerHys := GetProcAddress( DLLHandle, 'GetTriggerHys' );
  @SetTriggerHys := GetProcAddress( DLLHandle, 'SetTriggerHys' );
  @GetPXITriggerEnables := GetProcAddress( DLLHandle, 'GetPXITriggerEnables' );
  @SetPXITriggerEnables := GetProcAddress( DLLHandle, 'SetPXITriggerEnables' );
  @GetPXITriggerSlopes := GetProcAddress( DLLHandle, 'GetPXITriggerSlopes' );
  @SetPXITriggerSlopes := GetProcAddress( DLLHandle, 'SetPXITriggerSlopes' );
 
//  Control the digital outputs:
  @SetDigitalOutputs := GetProcAddress( DLLHandle, 'SetDigitalOutputs' );
  @GetDigitalOutputs := GetProcAddress( DLLHandle, 'GetDigitalOutputs' );
 
//  Square Wave Generator:
  @GetSquareWaveGenStatus := GetProcAddress( DLLHandle, 'GetSquareWaveGenStatus' );
  @GetSquareWaveGenFrequency := GetProcAddress( DLLHandle, 'GetSquareWaveGenFrequency' );
  @SetSquareWaveGenFrequency := GetProcAddress( DLLHandle, 'SetSquareWaveGenFrequency' );
 
//  Get information about the function generator:
  @GetFunctionGenStatus := GetProcAddress( DLLHandle, 'GetFunctionGenStatus' );
  @GetFuncGenMaxAmplitude := GetProcAddress( DLLHandle, 'GetFuncGenMaxAmplitude' );
 
//  Control the Arbitrary Waveform Generator:
  @GetFuncGenOutputOn := GetProcAddress( DLLHandle, 'GetFuncGenOutputOn' );
  @SetFuncGenOutputOn := GetProcAddress( DLLHandle, 'SetFuncGenOutputOn' );
  @GetFuncGenEnable := GetProcAddress( DLLHandle, 'GetFuncGenEnable' );
  @SetFuncGenEnable := GetProcAddress( DLLHandle, 'SetFuncGenEnable' );
  @GetFuncGenSignalType := GetProcAddress( DLLHandle, 'GetFuncGenSignalType' );
  @SetFuncGenSignalType := GetProcAddress( DLLHandle, 'SetFuncGenSignalType' );
  @GetFuncGenMode := GetProcAddress( DLLHandle, 'GetFuncGenMode' );
  @SetFuncGenMode := GetProcAddress( DLLHandle, 'SetFuncGenMode' );
  @GetFuncGenAmplitude := GetProcAddress( DLLHandle, 'GetFuncGenAmplitude' );
  @SetFuncGenAmplitude := GetProcAddress( DLLHandle, 'SetFuncGenAmplitude' );
  @GetFuncGenDCOffset := GetProcAddress( DLLHandle, 'GetFuncGenDCOffset' );
  @SetFuncGenDCOffset := GetProcAddress( DLLHandle, 'SetFuncGenDCOffset' );
  @GetFuncGenSymmetry := GetProcAddress( DLLHandle, 'GetFuncGenSymmetry' );
  @SetFuncGenSymmetry := GetProcAddress( DLLHandle, 'SetFuncGenSymmetry' );
  @GetFuncGenFrequency := GetProcAddress( DLLHandle, 'GetFuncGenFrequency' );
  @SetFuncGenFrequency := GetProcAddress( DLLHandle, 'SetFuncGenFrequency' );
  @SetFuncGenTrigSource := GetProcAddress( DLLHandle, 'SetFuncGenTrigSource' );
  @GetFuncGenTrigSource := GetProcAddress( DLLHandle, 'GetFuncGenTrigSource' );
  @FillFuncGenMemory := GetProcAddress( DLLHandle, 'FillFuncGenMemory' );
  @FuncGenBurst := GetProcAddress( DLLHandle, 'FuncGenBurst' );
 
//  Control multiple Arbitrary Waveform Generators:
  @GetFunctionGeneratorCount := GetProcAddress( DLLHandle, 'GetFunctionGeneratorCount' );
 
  @GetFuncGenOutputOnCh := GetProcAddress( DLLHandle, 'GetFuncGenOutputOnCh' );
  @SetFuncGenOutputOnCh := GetProcAddress( DLLHandle, 'SetFuncGenOutputOnCh' );
  @GetFuncGenEnableCh := GetProcAddress( DLLHandle, 'GetFuncGenEnableCh' );
  @SetFuncGenEnableCh := GetProcAddress( DLLHandle, 'SetFuncGenEnableCh' );
  @GetFuncGenSignalTypeCh := GetProcAddress( DLLHandle, 'GetFuncGenSignalTypeCh' );
  @SetFuncGenSignalTypeCh := GetProcAddress( DLLHandle, 'SetFuncGenSignalTypeCh' );
  @GetFuncGenModeCh := GetProcAddress( DLLHandle, 'GetFuncGenModeCh' );
  @SetFuncGenModeCh := GetProcAddress( DLLHandle, 'SetFuncGenModeCh' );
  @GetFuncGenMaxAmplitudeCh := GetProcAddress( DLLHandle, 'GetFuncGenMaxAmplitudeCh' );
  @GetFuncGenAmplitudeCh := GetProcAddress( DLLHandle, 'GetFuncGenAmplitudeCh' );
  @SetFuncGenAmplitudeCh := GetProcAddress( DLLHandle, 'SetFuncGenAmplitudeCh' );
  @GetFuncGenDCOffsetCh := GetProcAddress( DLLHandle, 'GetFuncGenDCOffsetCh' );
  @SetFuncGenDCOffsetCh := GetProcAddress( DLLHandle, 'SetFuncGenDCOffsetCh' );
  @GetFuncGenSymmetryCh := GetProcAddress( DLLHandle, 'GetFuncGenSymmetryCh' );
  @SetFuncGenSymmetryCh := GetProcAddress( DLLHandle, 'SetFuncGenSymmetryCh' );
  @GetFuncGenFrequencyCh := GetProcAddress( DLLHandle, 'GetFuncGenFrequencyCh' );
  @SetFuncGenFrequencyCh := GetProcAddress( DLLHandle, 'SetFuncGenFrequencyCh' );
  @GetFuncGenTrigSourceCh := GetProcAddress( DLLHandle, 'GetFuncGenTrigSourceCh' );
  @SetFuncGenTrigSourceCh := GetProcAddress( DLLHandle, 'SetFuncGenTrigSourceCh' );
  @FillFuncGenMemoryCh := GetProcAddress( DLLHandle, 'FillFuncGenMemoryCh' );
  @FuncGenBurstCh := GetProcAddress( DLLHandle, 'FuncGenBurstCh' );
 
//  Ohm measurements ( not available by default ):
  @SetupOhmMeasurements := GetProcAddress( DLLHandle, 'SetupOhmMeasurements' );
  @GetOhmValues := GetProcAddress( DLLHandle, 'GetOhmValues' );
 
//  I2C routines:
  @I2CWrite := GetProcAddress( DLLHandle, 'I2CWrite' );
  @I2CWriteNoStop := GetProcAddress( DLLHandle, 'I2CWriteNoStop' );
  @I2CRead := GetProcAddress( DLLHandle, 'I2CRead' );
  @I2CReadNoStop := GetProcAddress( DLLHandle, 'I2CReadNoStop' );
  @I2CGetSpeed := GetProcAddress( DLLHandle, 'I2CGetSpeed' );
  @I2CSetSpeed := GetProcAddress( DLLHandle, 'I2CSetSpeed' );
 
//  I2C routines for acces to I2C-buses other than that of the first instrument:
  @I2CWriteCh := GetProcAddress( DLLHandle, 'I2CWriteCh' );
  @I2CWriteNoStopCh := GetProcAddress( DLLHandle, 'I2CWriteNoStopCh' );
  @I2CReadCh := GetProcAddress( DLLHandle, 'I2CReadCh' );
  @I2CReadNoStopCh := GetProcAddress( DLLHandle, 'I2CReadNoStopCh' );
  @I2CGetSpeedCh := GetProcAddress( DLLHandle, 'I2CGetSpeedCh' );
  @I2CSetSpeedCh := GetProcAddress( DLLHandle, 'I2CSetSpeedCh' );
 
//  Obsolete routines, use is deprecated:
  @StartMeasurement := GetProcAddress( DLLHandle, 'StartMeasurement' );
 
  @GetMeasurement := GetProcAddress( DLLHandle, 'GetMeasurement' );
  @GetMeasurementCh := GetProcAddress( DLLHandle, 'GetMeasurementCh' );
  @GetMeasurementRaw := GetProcAddress( DLLHandle, 'GetMeasurementRaw' );
  @GetMeasurementRawCh := GetProcAddress( DLLHandle, 'GetMeasurementRawCh' );
  @GetOneMeasurement := GetProcAddress( DLLHandle, 'GetOneMeasurement' );
  @GetOneMeasurementCh := GetProcAddress( DLLHandle, 'GetOneMeasurementCh' );
  @GetOneMeasurementRaw := GetProcAddress( DLLHandle, 'GetOneMeasurementRaw' );
  @GetOneMeasurementRawCh := GetProcAddress( DLLHandle, 'GetOneMeasurementRawCh' );
  @ADC_GetData := GetProcAddress( DLLHandle, 'ADC_GetData' );
  @ADC_GetDataVolt := GetProcAddress( DLLHandle, 'ADC_GetDataVolt' );
 
  @GetMaxSampleFrequency := GetProcAddress( DLLHandle, 'GetMaxSampleFrequency' );
  @GetSampleFrequency := GetProcAddress( DLLHandle, 'GetSampleFrequency' );
  @SetSampleFrequency := GetProcAddress( DLLHandle, 'SetSampleFrequency' );
 
//  Streaming measurements:
  @SetDataReadyCallback := GetProcAddress( DLLHandle, 'SetDataReadyCallback' );
  @SetDataReadyEvent := GetProcAddress( DLLHandle, 'SetDataReadyEvent' );
  @SetTransferMode := GetProcAddress( DLLHandle, 'SetTransferMode' );
  @GetTransferMode := GetProcAddress( DLLHandle, 'GetTransferMode' );

end; { RetrieveAllProcAddresses }



procedure NilAllProcAddresses;
{* DESCRIPTION
 *   This routine is used to clear procedure addresses from the routines in the dll.
 * INPUT
 *   -
 * OUTPUT
 *   -
 *}
begin
//  Open / Close the instrument:
  @InitInstrument := nil;
  @ExitInstrument := nil;
 
//  Get information about the instrument:
  @GetCalibrationDate := nil;
  @GetSerialNumber := nil;
  @GetAvailableSensitivities := nil;
  @GetAvailableResolutions := nil;
  @GetNrChannels := nil;
  @GetMaxSampleFrequencyF := nil;
  @GetMaxRecordLength := nil;
  @GetDCLevelStatus := nil;
 
//  Measurement routines:
  @ADC_Start := nil;
  @ADC_Running := nil;
  @ADC_Abort := nil;
  @ADC_ForceTrig := nil;
  @ADC_Triggered := nil;
  @ADC_Ready := nil;
 
//  Retrieve the measured data:
  @ADC_GetDataCh := nil;
  @ADC_GetDataVoltCh := nil;
  @GetDigitalInputValues := nil;
  @GetOneDigitalValue := nil;
 
//  Control the input resolution in bits:
  @SetResolution := nil;
  @GetResolution := nil;
 
//  Control the instrument configuration:
  @SetInstrumentConfig := nil;
 
//  Control which channels are measured:
  @GetMeasureMode := nil;
  @SetMeasureMode := nil;
  @GetChEnabled := nil;
  @SetChEnabled := nil;
 
//  Control the time base:
  @GetRecordLength := nil;
  @SetRecordLength := nil;
  @GetPostSamples := nil;
  @SetPostSamples := nil;
  @GetSampleFrequencyF := nil;
  @SetSampleFrequencyF := nil;
  @GetExternalClock := nil;
  @SetExternalClock := nil;
 
//  Control the analog input channels:
  @GetSensitivity := nil;
  @SetSensitivity := nil;
  @GetAutoRanging := nil;
  @SetAutoRanging := nil;
  @GetCoupling := nil;
  @SetCoupling := nil;
  @GetDcLevel := nil;
  @SetDcLevel := nil;
 
//  Control the trigger system:
  @GetTriggerTimeOut := nil;
  @SetTriggerTimeOut := nil;
  @GetTriggerSource := nil;
  @SetTriggerSource := nil;
//  For more control, use these routines for trigger source, instead of the ones above:
  @GetTriggerSources := nil;
  @GetTriggerSourceOR := nil;
  @SetTriggerSourceOR := nil;
  @GetTriggerSourceAND := nil;
  @SetTriggerSourceAND := nil;
  @GetTriggerMode := nil;
  @SetTriggerMode := nil;
  @GetTriggerModeCh := nil;
  @SetTriggerModeCh := nil;
  @GetTriggerLevel := nil;
  @SetTriggerLevel := nil;
  @GetTriggerHys := nil;
  @SetTriggerHys := nil;
  @GetPXITriggerEnables := nil;
  @SetPXITriggerEnables := nil;
  @GetPXITriggerSlopes := nil;
  @SetPXITriggerSlopes := nil;
 
//  Control the digital outputs:
  @SetDigitalOutputs := nil;
  @GetDigitalOutputs := nil;
 
//  Square Wave Generator:
  @GetSquareWaveGenStatus := nil;
  @GetSquareWaveGenFrequency := nil;
  @SetSquareWaveGenFrequency := nil;
 
//  Get information about the function generator:
  @GetFunctionGenStatus := nil;
  @GetFuncGenMaxAmplitude := nil;
 
//  Control the Arbitrary Waveform Generator:
  @GetFuncGenOutputOn := nil;
  @SetFuncGenOutputOn := nil;
  @GetFuncGenEnable := nil;
  @SetFuncGenEnable := nil;
  @GetFuncGenSignalType := nil;
  @SetFuncGenSignalType := nil;
  @GetFuncGenMode := nil;
  @SetFuncGenMode := nil;
  @GetFuncGenAmplitude := nil;
  @SetFuncGenAmplitude := nil;
  @GetFuncGenDCOffset := nil;
  @SetFuncGenDCOffset := nil;
  @GetFuncGenSymmetry := nil;
  @SetFuncGenSymmetry := nil;
  @GetFuncGenFrequency := nil;
  @SetFuncGenFrequency := nil;
  @SetFuncGenTrigSource := nil;
  @GetFuncGenTrigSource := nil;
  @FillFuncGenMemory := nil;
  @FuncGenBurst := nil;
 
//  Control multiple Arbitrary Waveform Generators:
  @GetFunctionGeneratorCount := nil;
 
  @GetFuncGenOutputOnCh := nil;
  @SetFuncGenOutputOnCh := nil;
  @GetFuncGenEnableCh := nil;
  @SetFuncGenEnableCh := nil;
  @GetFuncGenSignalTypeCh := nil;
  @SetFuncGenSignalTypeCh := nil;
  @GetFuncGenModeCh := nil;
  @SetFuncGenModeCh := nil;
  @GetFuncGenMaxAmplitudeCh := nil;
  @GetFuncGenAmplitudeCh := nil;
  @SetFuncGenAmplitudeCh := nil;
  @GetFuncGenDCOffsetCh := nil;
  @SetFuncGenDCOffsetCh := nil;
  @GetFuncGenSymmetryCh := nil;
  @SetFuncGenSymmetryCh := nil;
  @GetFuncGenFrequencyCh := nil;
  @SetFuncGenFrequencyCh := nil;
  @GetFuncGenTrigSourceCh := nil;
  @SetFuncGenTrigSourceCh := nil;
  @FillFuncGenMemoryCh := nil;
  @FuncGenBurstCh := nil;
 
//  Ohm measurements ( not available by default ):
  @SetupOhmMeasurements := nil;
  @GetOhmValues := nil;
 
//  I2C routines:
  @I2CWrite := nil;
  @I2CWriteNoStop := nil;
  @I2CRead := nil;
  @I2CReadNoStop := nil;
  @I2CGetSpeed := nil;
  @I2CSetSpeed := nil;
 
//  I2C routines for acces to I2C-buses other than that of the first instrument:
  @I2CWriteCh := nil;
  @I2CWriteNoStopCh := nil;
  @I2CReadCh := nil;
  @I2CReadNoStopCh := nil;
  @I2CGetSpeedCh := nil;
  @I2CSetSpeedCh := nil;
 
//  Obsolete routines, use is deprecated:
  @StartMeasurement := nil;
 
  @GetMeasurement := nil;
  @GetMeasurementCh := nil;
  @GetMeasurementRaw := nil;
  @GetMeasurementRawCh := nil;
  @GetOneMeasurement := nil;
  @GetOneMeasurementCh := nil;
  @GetOneMeasurementRaw := nil;
  @GetOneMeasurementRawCh := nil;
  @ADC_GetData := nil;
  @ADC_GetDataVolt := nil;
 
  @GetMaxSampleFrequency := nil;
  @GetSampleFrequency := nil;
  @SetSampleFrequency := nil;
 
//  Streaming measurements:
  @SetDataReadyCallback := nil;
  @SetDataReadyEvent := nil;
  @SetTransferMode := nil;
  @GetTransferMode := nil;

end; { NilAllProcAddresses }



end.

