//---------------------------------------------------------------------------
/* DESCRIPTION
 *   This unit contains all definitions and declarations that are required
 *   to use a TiePie instrument in a C++ builder application.
 *   This is a universal unit, therefor it may contain definitions and declarations
 *   that are not supported by the instrument you are writing software for.
 *   Using these will be handled properly by the dll and should not cause problems
 * NOTE
 *   Despite the care taken to generate the dll's and the accomanying files,
 *   TiePie engineering can not be held responsible for any damage as a result of using
 *   the dll's and the accompanying source files.
 * COPYRIGHT
 *   TiePie engineering
 */


#ifndef TiePieDLLObjH
#define TiePieDLLObjH
//---------------------------------------------------------------------------

#include <Classes.hpp>  // Pascal unit, used for ancestor TComponent.

#define TP_TYPEDEFS
#define TP_NOSTATICIMPORT
#include "tiepie.h"


class TTiePieInstrument : public Classes::TComponent {
  private:
    // Internal:
    HMODULE FDLLHandle;

    // Pointers to DLL routines:
// Open / Close the instrument:
    LPFN_InitInstrument FInitInstrument;
    LPFN_ExitInstrument FExitInstrument;
 
// Get information about the instrument:
    LPFN_GetCalibrationDate FGetCalibrationDate;
    LPFN_GetSerialNumber FGetSerialNumber;
    LPFN_GetAvailableSensitivities FGetAvailableSensitivities;
    LPFN_GetAvailableResolutions FGetAvailableResolutions;
    LPFN_GetNrChannels FGetNrChannels;
    LPFN_GetMaxSampleFrequencyF FGetMaxSampleFrequencyF;
    LPFN_GetMaxRecordLength FGetMaxRecordLength;
    LPFN_GetDCLevelStatus FGetDCLevelStatus;
 
// Measurement routines:
    LPFN_ADC_Start FADC_Start;
    LPFN_ADC_Running FADC_Running;
    LPFN_ADC_Abort FADC_Abort;
    LPFN_ADC_ForceTrig FADC_ForceTrig;
    LPFN_ADC_Triggered FADC_Triggered;
    LPFN_ADC_Ready FADC_Ready;
 
// Retrieve the measured data:
    LPFN_ADC_GetDataCh FADC_GetDataCh;
    LPFN_ADC_GetDataVoltCh FADC_GetDataVoltCh;
    LPFN_GetDigitalInputValues FGetDigitalInputValues;
    LPFN_GetOneDigitalValue FGetOneDigitalValue;
 
// Control the input resolution in bits:
    LPFN_SetResolution FSetResolution;
    LPFN_GetResolution FGetResolution;
 
// Control the instrument configuration:
    LPFN_SetInstrumentConfig FSetInstrumentConfig;
 
// Control which channels are measured:
    LPFN_GetMeasureMode FGetMeasureMode;
    LPFN_SetMeasureMode FSetMeasureMode;
    LPFN_GetChEnabled FGetChEnabled;
    LPFN_SetChEnabled FSetChEnabled;
 
// Control the time base:
    LPFN_GetRecordLength FGetRecordLength;
    LPFN_SetRecordLength FSetRecordLength;
    LPFN_GetPostSamples FGetPostSamples;
    LPFN_SetPostSamples FSetPostSamples;
    LPFN_GetSampleFrequencyF FGetSampleFrequencyF;
    LPFN_SetSampleFrequencyF FSetSampleFrequencyF;
    LPFN_GetExternalClock FGetExternalClock;
    LPFN_SetExternalClock FSetExternalClock;
 
// Control the analog input channels:
    LPFN_GetSensitivity FGetSensitivity;
    LPFN_SetSensitivity FSetSensitivity;
    LPFN_GetAutoRanging FGetAutoRanging;
    LPFN_SetAutoRanging FSetAutoRanging;
    LPFN_GetCoupling FGetCoupling;
    LPFN_SetCoupling FSetCoupling;
    LPFN_GetDcLevel FGetDcLevel;
    LPFN_SetDcLevel FSetDcLevel;
 
// Control the trigger system:
    LPFN_GetTriggerTimeOut FGetTriggerTimeOut;
    LPFN_SetTriggerTimeOut FSetTriggerTimeOut;
    LPFN_GetTriggerSource FGetTriggerSource;
    LPFN_SetTriggerSource FSetTriggerSource;
// For more control, use these routines for trigger source, instead of the ones above:
    LPFN_GetTriggerSources FGetTriggerSources;
    LPFN_GetTriggerSourceOR FGetTriggerSourceOR;
    LPFN_SetTriggerSourceOR FSetTriggerSourceOR;
    LPFN_GetTriggerSourceAND FGetTriggerSourceAND;
    LPFN_SetTriggerSourceAND FSetTriggerSourceAND;
    LPFN_GetTriggerMode FGetTriggerMode;
    LPFN_SetTriggerMode FSetTriggerMode;
    LPFN_GetTriggerModeCh FGetTriggerModeCh;
    LPFN_SetTriggerModeCh FSetTriggerModeCh;
    LPFN_GetTriggerLevel FGetTriggerLevel;
    LPFN_SetTriggerLevel FSetTriggerLevel;
    LPFN_GetTriggerHys FGetTriggerHys;
    LPFN_SetTriggerHys FSetTriggerHys;
    LPFN_GetPXITriggerEnables FGetPXITriggerEnables;
    LPFN_SetPXITriggerEnables FSetPXITriggerEnables;
    LPFN_GetPXITriggerSlopes FGetPXITriggerSlopes;
    LPFN_SetPXITriggerSlopes FSetPXITriggerSlopes;
 
// Control the digital outputs:
    LPFN_SetDigitalOutputs FSetDigitalOutputs;
    LPFN_GetDigitalOutputs FGetDigitalOutputs;
 
// Square Wave Generator:
    LPFN_GetSquareWaveGenStatus FGetSquareWaveGenStatus;
    LPFN_GetSquareWaveGenFrequency FGetSquareWaveGenFrequency;
    LPFN_SetSquareWaveGenFrequency FSetSquareWaveGenFrequency;
 
// Get information about the function generator:
    LPFN_GetFunctionGenStatus FGetFunctionGenStatus;
    LPFN_GetFuncGenMaxAmplitude FGetFuncGenMaxAmplitude;
 
// Control the Arbitrary Waveform Generator:
    LPFN_GetFuncGenOutputOn FGetFuncGenOutputOn;
    LPFN_SetFuncGenOutputOn FSetFuncGenOutputOn;
    LPFN_GetFuncGenEnable FGetFuncGenEnable;
    LPFN_SetFuncGenEnable FSetFuncGenEnable;
    LPFN_GetFuncGenSignalType FGetFuncGenSignalType;
    LPFN_SetFuncGenSignalType FSetFuncGenSignalType;
    LPFN_GetFuncGenMode FGetFuncGenMode;
    LPFN_SetFuncGenMode FSetFuncGenMode;
    LPFN_GetFuncGenAmplitude FGetFuncGenAmplitude;
    LPFN_SetFuncGenAmplitude FSetFuncGenAmplitude;
    LPFN_GetFuncGenDCOffset FGetFuncGenDCOffset;
    LPFN_SetFuncGenDCOffset FSetFuncGenDCOffset;
    LPFN_GetFuncGenSymmetry FGetFuncGenSymmetry;
    LPFN_SetFuncGenSymmetry FSetFuncGenSymmetry;
    LPFN_GetFuncGenFrequency FGetFuncGenFrequency;
    LPFN_SetFuncGenFrequency FSetFuncGenFrequency;
    LPFN_SetFuncGenTrigSource FSetFuncGenTrigSource;
    LPFN_GetFuncGenTrigSource FGetFuncGenTrigSource;
    LPFN_FillFuncGenMemory FFillFuncGenMemory;
    LPFN_FuncGenBurst FFuncGenBurst;
 
// Control multiple Arbitrary Waveform Generators:
    LPFN_GetFunctionGeneratorCount FGetFunctionGeneratorCount;
 
    LPFN_GetFuncGenOutputOnCh FGetFuncGenOutputOnCh;
    LPFN_SetFuncGenOutputOnCh FSetFuncGenOutputOnCh;
    LPFN_GetFuncGenEnableCh FGetFuncGenEnableCh;
    LPFN_SetFuncGenEnableCh FSetFuncGenEnableCh;
    LPFN_GetFuncGenSignalTypeCh FGetFuncGenSignalTypeCh;
    LPFN_SetFuncGenSignalTypeCh FSetFuncGenSignalTypeCh;
    LPFN_GetFuncGenModeCh FGetFuncGenModeCh;
    LPFN_SetFuncGenModeCh FSetFuncGenModeCh;
    LPFN_GetFuncGenMaxAmplitudeCh FGetFuncGenMaxAmplitudeCh;
    LPFN_GetFuncGenAmplitudeCh FGetFuncGenAmplitudeCh;
    LPFN_SetFuncGenAmplitudeCh FSetFuncGenAmplitudeCh;
    LPFN_GetFuncGenDCOffsetCh FGetFuncGenDCOffsetCh;
    LPFN_SetFuncGenDCOffsetCh FSetFuncGenDCOffsetCh;
    LPFN_GetFuncGenSymmetryCh FGetFuncGenSymmetryCh;
    LPFN_SetFuncGenSymmetryCh FSetFuncGenSymmetryCh;
    LPFN_GetFuncGenFrequencyCh FGetFuncGenFrequencyCh;
    LPFN_SetFuncGenFrequencyCh FSetFuncGenFrequencyCh;
    LPFN_GetFuncGenTrigSourceCh FGetFuncGenTrigSourceCh;
    LPFN_SetFuncGenTrigSourceCh FSetFuncGenTrigSourceCh;
    LPFN_FillFuncGenMemoryCh FFillFuncGenMemoryCh;
    LPFN_FuncGenBurstCh FFuncGenBurstCh;
 
// Ohm measurements ( not available by default ):
    LPFN_SetupOhmMeasurements FSetupOhmMeasurements;
    LPFN_GetOhmValues FGetOhmValues;
 
// I2C routines:
    LPFN_I2CWrite FI2CWrite;
    LPFN_I2CWriteNoStop FI2CWriteNoStop;
    LPFN_I2CRead FI2CRead;
    LPFN_I2CReadNoStop FI2CReadNoStop;
    LPFN_I2CGetSpeed FI2CGetSpeed;
    LPFN_I2CSetSpeed FI2CSetSpeed;
 
// I2C routines for acces to I2C-buses other than that of the first instrument:
    LPFN_I2CWriteCh FI2CWriteCh;
    LPFN_I2CWriteNoStopCh FI2CWriteNoStopCh;
    LPFN_I2CReadCh FI2CReadCh;
    LPFN_I2CReadNoStopCh FI2CReadNoStopCh;
    LPFN_I2CGetSpeedCh FI2CGetSpeedCh;
    LPFN_I2CSetSpeedCh FI2CSetSpeedCh;
 
// Obsolete routines, use is deprecated:
    LPFN_StartMeasurement FStartMeasurement;
 
    LPFN_GetMeasurement FGetMeasurement;
    LPFN_GetMeasurementCh FGetMeasurementCh;
    LPFN_GetMeasurementRaw FGetMeasurementRaw;
    LPFN_GetMeasurementRawCh FGetMeasurementRawCh;
    LPFN_GetOneMeasurement FGetOneMeasurement;
    LPFN_GetOneMeasurementCh FGetOneMeasurementCh;
    LPFN_GetOneMeasurementRaw FGetOneMeasurementRaw;
    LPFN_GetOneMeasurementRawCh FGetOneMeasurementRawCh;
    LPFN_ADC_GetData FADC_GetData;
    LPFN_ADC_GetDataVolt FADC_GetDataVolt;
 
    LPFN_GetMaxSampleFrequency FGetMaxSampleFrequency;
    LPFN_GetSampleFrequency FGetSampleFrequency;
    LPFN_SetSampleFrequency FSetSampleFrequency;
 
// Streaming measurements:
    LPFN_SetDataReadyCallback FSetDataReadyCallback;
    LPFN_SetDataReadyEvent FSetDataReadyEvent;
    LPFN_SetTransferMode FSetTransferMode;
    LPFN_GetTransferMode FGetTransferMode;


    void __fastcall RetrieveAllProcAddresses( void );
  public:
    __fastcall virtual TTiePieInstrument( TComponent* AOwner );
    __fastcall virtual ~TTiePieInstrument( void );

    bool __fastcall OpenDLL( LPCTSTR sPath );

    // Routines routed to the DLL:
// Open / Close the instrument:
    word __fastcall InitInstrument( word wInstrumentCount );
    word __fastcall ExitInstrument( void );
 
// Get information about the instrument:
    word __fastcall GetCalibrationDate( dword* dwDate );
    word __fastcall GetSerialNumber( dword* dwSerialNumber );
    word __fastcall GetAvailableSensitivities( double* dSensitivities );
    word __fastcall GetAvailableResolutions( double* dResolutions );
    word __fastcall GetNrChannels( word* wValue );
    double __fastcall GetMaxSampleFrequencyF( void );
    dword __fastcall GetMaxRecordLength( void );
    dword __fastcall GetDCLevelStatus( void );
 
// Measurement routines:
    word __fastcall ADC_Start( void );
    word __fastcall ADC_Running( void );
    word __fastcall ADC_Abort( void );
    word __fastcall ADC_ForceTrig( void );
    word __fastcall ADC_Triggered( void );
    word __fastcall ADC_Ready( void );
 
// Retrieve the measured data:
    word __fastcall ADC_GetDataCh( word wCh , word* wChData );
    word __fastcall ADC_GetDataVoltCh( word wCh , double* dChData );
    word __fastcall GetDigitalInputValues( word* wValues );
    word __fastcall GetOneDigitalValue( dword dwIndex , word* wValue );
 
// Control the input resolution in bits:
    word __fastcall SetResolution( byte byValue );
    word __fastcall GetResolution( byte* byValue );
 
// Control the instrument configuration:
    word __fastcall SetInstrumentConfig( word wMode );
 
// Control which channels are measured:
    word __fastcall GetMeasureMode( byte* byMode );
    word __fastcall SetMeasureMode( byte byMode );
    word __fastcall GetChEnabled( word wCh , byte* byEnabled );
    word __fastcall SetChEnabled( word wCh , byte byEnabled );
 
// Control the time base:
    dword __fastcall GetRecordLength( void );
    word __fastcall SetRecordLength( dword dwRecordLength );
    dword __fastcall GetPostSamples( void );
    word __fastcall SetPostSamples( dword dwPostSampleCount );
    double __fastcall GetSampleFrequencyF( void );
    word __fastcall SetSampleFrequencyF( double* dFreq );
    word __fastcall GetExternalClock( word* wMode );
    word __fastcall SetExternalClock( word wMode );
 
// Control the analog input channels:
    word __fastcall GetSensitivity( byte byCh , double* dSensitivity );
    word __fastcall SetSensitivity( byte byCh , double* dSensitivity );
    word __fastcall GetAutoRanging( byte byCh , byte* byMode );
    word __fastcall SetAutoRanging( byte byCh , byte byMode );
    word __fastcall GetCoupling( byte byCh , byte* byMode );
    word __fastcall SetCoupling( byte byCh , byte byMode );
    word __fastcall GetDcLevel( byte byCh , double* dDcLevel );
    word __fastcall SetDcLevel( byte byCh , double dDcLevel );
 
// Control the trigger system:
    dword __fastcall GetTriggerTimeOut( void );
    word __fastcall SetTriggerTimeOut( dword dwTimeout );
    word __fastcall GetTriggerSource( byte* byTrigSource );
    word __fastcall SetTriggerSource( byte byTrigSource );
// For more control, use these routines for trigger source, instead of the ones above:
    word __fastcall GetTriggerSources( int64* nTrigMask );
    word __fastcall GetTriggerSourceOR( int64* nTrigMask );
    word __fastcall SetTriggerSourceOR( int64 nTrigMask );
    word __fastcall GetTriggerSourceAND( int64* nTrigMask );
    word __fastcall SetTriggerSourceAND( int64 nTrigMask );
    word __fastcall GetTriggerMode( byte* byMode );
    word __fastcall SetTriggerMode( byte byMode );
    word __fastcall GetTriggerModeCh( byte byCh , byte* byMode );
    word __fastcall SetTriggerModeCh( byte byCh , byte byMode );
    word __fastcall GetTriggerLevel( byte byCh , double* dLevel );
    word __fastcall SetTriggerLevel( byte byCh , double dLevel );
    word __fastcall GetTriggerHys( byte byCh , double* dHysteresis );
    word __fastcall SetTriggerHys( byte byCh , double dHysteresis );
    word __fastcall GetPXITriggerEnables( byte* byEnables );
    word __fastcall SetPXITriggerEnables( byte byEnables );
    word __fastcall GetPXITriggerSlopes( byte* bySlopes );
    word __fastcall SetPXITriggerSlopes( byte bySlopes );
 
// Control the digital outputs:
    word __fastcall SetDigitalOutputs( byte byValue );
    word __fastcall GetDigitalOutputs( byte* byValue );
 
// Square Wave Generator:
    word __fastcall GetSquareWaveGenStatus( void );
    dword __fastcall GetSquareWaveGenFrequency( void );
    word __fastcall SetSquareWaveGenFrequency( dword* dwFreq );
 
// Get information about the function generator:
    word __fastcall GetFunctionGenStatus( void );
    word __fastcall GetFuncGenMaxAmplitude( double* dMaxAmplitude );
 
// Control the Arbitrary Waveform Generator:
    word __fastcall GetFuncGenOutputOn( word* wValue );
    word __fastcall SetFuncGenOutputOn( word wValue );
    word __fastcall GetFuncGenEnable( word* wValue );
    word __fastcall SetFuncGenEnable( word wValue );
    word __fastcall GetFuncGenSignalType( word* wValue );
    word __fastcall SetFuncGenSignalType( word wValue );
    word __fastcall GetFuncGenMode( dword* dwMode );
    word __fastcall SetFuncGenMode( dword dwMode );
    word __fastcall GetFuncGenAmplitude( double* dValue );
    word __fastcall SetFuncGenAmplitude( double dValue );
    word __fastcall GetFuncGenDCOffset( double* dValue );
    word __fastcall SetFuncGenDCOffset( double dValue );
    word __fastcall GetFuncGenSymmetry( double* dValue );
    word __fastcall SetFuncGenSymmetry( double dValue );
    word __fastcall GetFuncGenFrequency( double* dValue );
    word __fastcall SetFuncGenFrequency( double* dValue );
    word __fastcall SetFuncGenTrigSource( byte byTrigSource );
    word __fastcall GetFuncGenTrigSource( byte* byTrigSource );
    word __fastcall FillFuncGenMemory( dword dwSampleCount , word* FuncGenData );
    word __fastcall FuncGenBurst( word wNrPeriods );
 
// Control multiple Arbitrary Waveform Generators:
    word __fastcall GetFunctionGeneratorCount( void );
 
    word __fastcall GetFuncGenOutputOnCh( word wCh , word* wValue );
    word __fastcall SetFuncGenOutputOnCh( word wCh , word wValue );
    word __fastcall GetFuncGenEnableCh( word wCh , word* wValue );
    word __fastcall SetFuncGenEnableCh( word wCh , word wValue );
    word __fastcall GetFuncGenSignalTypeCh( word wCh , word* wValue );
    word __fastcall SetFuncGenSignalTypeCh( word wCh , word wValue );
    word __fastcall GetFuncGenModeCh( word wCh , dword* dwMode );
    word __fastcall SetFuncGenModeCh( word wCh , dword dwMode );
    word __fastcall GetFuncGenMaxAmplitudeCh( word wCh , double* dValue );
    word __fastcall GetFuncGenAmplitudeCh( word wCh , double* dValue );
    word __fastcall SetFuncGenAmplitudeCh( word wCh , double dValue );
    word __fastcall GetFuncGenDCOffsetCh( word wCh , double* dValue );
    word __fastcall SetFuncGenDCOffsetCh( word wCh , double dValue );
    word __fastcall GetFuncGenSymmetryCh( word wCh , double* dValue );
    word __fastcall SetFuncGenSymmetryCh( word wCh , double dValue );
    word __fastcall GetFuncGenFrequencyCh( word wCh , double* dValue );
    word __fastcall SetFuncGenFrequencyCh( word wCh , double* dValue );
    word __fastcall GetFuncGenTrigSourceCh( word wCh , byte* byTrigSource );
    word __fastcall SetFuncGenTrigSourceCh( word wCh , byte byTrigSource );
    word __fastcall FillFuncGenMemoryCh( word wCh , dword dwSampleCount , word* FuncGenData );
    word __fastcall FuncGenBurstCh( word wCh , word wNrPeriods );
 
// Ohm measurements ( not available by default ):
    word __fastcall SetupOhmMeasurements( word wMode );
    word __fastcall GetOhmValues( double* dValue1 , double* dValue2 );
 
// I2C routines:
    word __fastcall I2CWrite( dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CWriteNoStop( dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CRead( dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CReadNoStop( dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CGetSpeed( dword* dwSpeed );
    word __fastcall I2CSetSpeed( dword* dwSpeed );
 
// I2C routines for acces to I2C-buses other than that of the first instrument:
    word __fastcall I2CWriteCh( word wCh , dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CWriteNoStopCh( word wCh , dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CReadCh( word wCh , dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CReadNoStopCh( word wCh , dword dwAddress , pointer pBuf , dword dwSize );
    word __fastcall I2CGetSpeedCh( word wCh , dword* dwSpeed );
    word __fastcall I2CSetSpeedCh( word wCh , dword* dwSpeed );
 
// Obsolete routines, use is deprecated:
    word __fastcall StartMeasurement( void );
 
    word __fastcall GetMeasurement( double* dCh1 , double* dCh2 );
    word __fastcall GetMeasurementCh( word wCh , double* dChData );
    word __fastcall GetMeasurementRaw( word* wCh1 , word* wCh2 );
    word __fastcall GetMeasurementRawCh( word wCh , word* wChData );
    word __fastcall GetOneMeasurement( dword dwIndex , double* dCh1 , double* dCh2 );
    word __fastcall GetOneMeasurementCh( word wCh , dword dwIndex , double* dChData );
    word __fastcall GetOneMeasurementRaw( dword dwIndex , word* wCh1 , word* wCh2 );
    word __fastcall GetOneMeasurementRawCh( word wCh , dword dwIndex , word* wChData );
    word __fastcall ADC_GetData( word* wCh1 , word* wCh2 );
    word __fastcall ADC_GetDataVolt( double* dCh1 , double* dCh2 );
 
    dword __fastcall GetMaxSampleFrequency( void );
    dword __fastcall GetSampleFrequency( void );
    word __fastcall SetSampleFrequency( dword* dwFreq );
 
// Streaming measurements:
    word __fastcall SetDataReadyCallback( TDataReady pAddress );
    word __fastcall SetDataReadyEvent( HANDLE hEvent );
    word __fastcall SetTransferMode( dword dwMode );
    word __fastcall GetTransferMode( dword* dwMode );

};

//---------------------------------------------------------------------------
#endif
